from __future__ import absolute_import

import string

from . import SDK_VERSION

FILE_GITIGNORE = """
# Ignore build generated files
build

# Ignore waf lock file
.lock-waf*
"""

FILE_WSCRIPT = """
#
# This file is the default set of rules to compile a Pebble project.
#
# Feel free to customize this to your needs.
#

import os.path

top = '.'
out = 'build'

def options(ctx):
    ctx.load('pebble_sdk')

def configure(ctx):
    ctx.load('pebble_sdk')

def build(ctx):
    ctx.load('pebble_sdk')

    build_worker = os.path.exists('worker_src')
    binaries = []

    for p in ctx.env.TARGET_PLATFORMS:
        ctx.set_env(ctx.all_envs[p])
        ctx.set_group(ctx.env.PLATFORM_NAME)
        app_elf='{}/pebble-app.elf'.format(ctx.env.BUILD_DIR)
        ctx.pbl_program(source=ctx.path.ant_glob('src/**/*.c'),
        target=app_elf)

        if build_worker:
            worker_elf='{}/pebble-worker.elf'.format(ctx.env.BUILD_DIR)
            binaries.append({'platform': p, 'app_elf': app_elf, 'worker_elf': worker_elf})
            ctx.pbl_worker(source=ctx.path.ant_glob('worker_src/**/*.c'),
            target=worker_elf)
        else:
            binaries.append({'platform': p, 'app_elf': app_elf})

    ctx.set_group('bundle')
    ctx.pbl_bundle(binaries=binaries, js=ctx.path.ant_glob('src/js/**/*.js'))
"""

FILE_WSCRIPT_LEGACY2 = """
#
# This file is the default set of rules to compile a Pebble project.
#
# Feel free to customize this to your needs.
#

import os.path

top = '.'
out = 'build'

def options(ctx):
    ctx.load('pebble_sdk')

def configure(ctx):
    ctx.load('pebble_sdk')

def build(ctx):
    ctx.load('pebble_sdk')

    ctx.pbl_program(source=ctx.path.ant_glob('src/**/*.c'),
                    target='pebble-app.elf')

    if os.path.exists('worker_src'):
        ctx.pbl_worker(source=ctx.path.ant_glob('worker_src/**/*.c'),
                        target='pebble-worker.elf')
        ctx.pbl_bundle(elf='pebble-app.elf',
                        worker_elf='pebble-worker.elf',
                        js=ctx.path.ant_glob('src/js/**/*.js'))
    else:
        ctx.pbl_bundle(elf='pebble-app.elf',
                        js=ctx.path.ant_glob('src/js/**/*.js'))
"""

FILE_SIMPLE_MAIN = """#include <pebble.h>

int main(void)
{
	app_event_loop();
}
"""

FILE_DUMMY_WORKER = """#include <pebble_worker.h>

int main(void)
{
	worker_event_loop();
}
"""

FILE_DUMMY_MAIN = """#include <pebble.h>

static Window* window = NULL;
static TextLayer* textLayer = NULL;

static void selectClickHandler(ClickRecognizerRef recognizer, void* context) 
{
	text_layer_set_text(textLayer, "Select");
}

static void upClickHandler(ClickRecognizerRef recognizer, void* context)
{
	text_layer_set_text(textLayer, "Up");
}

static void downClickHandler(ClickRecognizerRef recognizer, void* context)
{
	text_layer_set_text(textLayer, "Down");
}

static void clickConfigProvider(void *context)
{
	window_single_click_subscribe(BUTTON_ID_SELECT, selectClickHandler);
	window_single_click_subscribe(BUTTON_ID_UP, upClickHandler);
	window_single_click_subscribe(BUTTON_ID_DOWN, downClickHandler);
}

static void windowLoad(Window* window)
{
	Layer* windowLayer = window_get_root_layer(window);
	GRect bounds = layer_get_bounds(windowLayer);

	textLayer = text_layer_create((GRect) { .origin = { 0, 72 }, .size = { bounds.size.w, 20 } });
	text_layer_set_text(textLayer, "Press a button");
	text_layer_set_text_alignment(textLayer, GTextAlignmentCenter);
	layer_add_child(windowLayer, text_layer_get_layer(textLayer));
}

static void windowUnload(Window *window)
{
	text_layer_destroy(textLayer);
}

static void init(void)
{
	window = window_create();
	window_set_click_config_provider(window, clickConfigProvider);
	window_set_window_handlers(window, (WindowHandlers) {
		.load = windowLoad,
		.unload = windowUnload,
	});
	const bool animated = true;
	window_stack_push(window, animated);
}

static void deinit(void)
{
	window_destroy(window);
}

int main(void)
{
	init();
		APP_LOG(APP_LOG_LEVEL_DEBUG, "Done initializing, pushed window: %p", window);
		app_event_loop();
	deinit();
}
"""

DICT_DUMMY_APPINFO = {
    'company_name': 'Allan175',
    'version_label': '1.0',
    'target_platform': '["aplite", "basalt"]',
    'sdk_version': SDK_VERSION,
    'is_watchface': 'false',
    'app_keys': """{
    "dummy": 0
  }""",
    'resources_media': '[]'
}

FILE_DUMMY_APPINFO = string.Template("""{
  "uuid": "${uuid}",
  "shortName": "${project_name}",
  "longName": "${project_name}",
  "companyName": "${company_name}",
  "versionLabel": "${version_label}",
  "sdkVersion": "${sdk_version}",
  "targetPlatforms": ${target_platform},
  "watchapp": {
    "watchface": ${is_watchface}
  },
  "appKeys": ${app_keys},
  "resources": {
    "media": ${resources_media}
  }
}
""")

FILE_DUMMY_JAVASCRIPT_SRC = """\
Pebble.addEventListener("ready",
    function(e) {
        console.log("Hello world! - Sent from your javascript application.");
    }
);
"""

FILE_DUMMY_WATCHFACE = """#include <pebble.h>

static Window* window = NULL;
static TextLayer* timeLayer = NULL;

static void tickHandler(struct tm* tickTime, TimeUnits unitsChanged)
{
	static char timeString[20];

	if (clock_is_24h_style())
		strftime(timeString, sizeof(timeString), "%H:%M", tickTime);
	else
		strftime(timeString, sizeof(timeString), "%I:%M", tickTime);

	text_layer_set_text(timeLayer, timeString);
}

static void windowLoad(Window* window)
{
	Layer* windowLayer = window_get_root_layer(window);
	GRect bounds = layer_get_bounds(windowLayer);

	timeLayer = text_layer_create((GRect) { .origin = { 0, 72 }, .size = { bounds.size.w, 20 } });
	text_layer_set_text(timeLayer, "Pebble");
	text_layer_set_text_alignment(timeLayer, GTextAlignmentCenter);
	layer_add_child(windowLayer, text_layer_get_layer(timeLayer));
}

static void windowUnload(Window *window)
{
	text_layer_destroy(timeLayer);
}

static void init(void)
{
	window = window_create();
	window_set_window_handlers(window, (WindowHandlers) {
		.load = windowLoad,
		.unload = windowUnload,
	});
	const bool animated = true;
	window_stack_push(window, animated);

	tick_timer_service_subscribe(MINUTE_UNIT, tickHandler);
}

static void deinit(void)
{
	tick_timer_service_unsubscribe();
	window_destroy(window);
}

int main(void)
{
	init();
		APP_LOG(APP_LOG_LEVEL_DEBUG, "Done initializing, pushed window: %p", window);
		app_event_loop();
	deinit();
}
"""

